ERDOS Package Reference
=======================

.. automodule:: erdos
   :members: connect_source, connect_sink, connect_one_in_one_out,
      connect_two_in_one_out, connect_one_in_two_out,
      reset, run, run_async, profile_method, NodeHandle
